@@ -146,16 +146,16 @@ get_macfileinfo(PerlIO *infile, char *file, HV *info)
 
   if (si->sample_rate) {
     double total_samples = (double)(((si->blocks_per_frame * (si->total_frames - 1)) + si->final_frame));
-    double total_seconds = total_samples / si->sample_rate;
+    uint32_t total_ms = (total_samples * 1000) / si->sample_rate;
 
     my_hv_store(info, "samplerate", newSViv(si->sample_rate));
     my_hv_store(info, "channels", newSViv(si->channels));
-    my_hv_store(info, "song_length_ms", newSVuv(total_seconds * 1000));
-    my_hv_store(info, "bitrate", newSVuv((double)(8 * ((si->file_size - si->audio_start_offset) / total_seconds))));
+    my_hv_store(info, "song_length_ms", newSVuv(total_ms));
+    my_hv_store(info, "bitrate", newSVuv((double)(8 * ((si->file_size - si->audio_start_offset) / (total_ms * 1.0 / 1000)))));
 
     my_hv_store(info, "file_size", newSVnv(si->file_size));
     my_hv_store(info, "compression", newSVpv(si->compression, 0));
-    my_hv_store(info, "version", newSVnv((double)(si->version / 1000.0)));
+    my_hv_store(info, "version", newSVpvf( "%.2f", (double)(si->version / 1000.0) ) );
   }
 
 out:
